@@ -1,5 +1,3 @@
-context("Load/save RDA files")
-
 cas <- smart_read("cas500.csv")
 not_a_df <- 1:10
 rda <- file.path(tempdir(), "my_files.rda")
@@ -9,7 +7,7 @@ save(cas, iris, not_a_df, file = rda)
 
 test_that("Load returns list of data frames", {
     res <- load_rda(rda)
-    expect_is(res, "list")
+    expect_type(res, "list")
     expect_equal(names(res), c("cas", "iris"))
     expect_equal(res$iris, iris)
     expect_equal(res$cas, cas)
