@@ -1,5 +1,3 @@
-context("Convert missing to categorical")
-
 cas <- smart_read("cas500.csv")
 # cas <- smart_read("tests/testthat/cas500.csv")
 
@@ -9,9 +7,10 @@ test_that("Numeric variables converted to missing/not-missing", {
         d$rightfoot_miss,
         factor(ifelse(is.na(d$rightfoot), "missing", "observed"))
     )
-    expect_equivalent(
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
 
@@ -21,9 +20,10 @@ test_that("Categorical variables converted to missing", {
         as.character(d$cellsource_miss),
         ifelse(is.na(d$cellsource), "missing", as.character(d$cellsource))
     )
-    expect_equivalent(
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
 
@@ -33,9 +33,10 @@ svy <- svydesign(~dnum+snum, weights = ~pw, fpc = ~fpc1+fpc2, data = apiclus2)
 
 test_that("Conversion to categorical works for surveys", {
     d <- missingToCat(svy, c("api00", "stype"))
-    expect_is(d, "survey.design2")
-    expect_equivalent(
+    expect_s3_class(d, "survey.design2")
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
