@@ -1,5 +1,3 @@
-context("Sort data by value of variable(s)")
-
 cas <- smart_read("cas500.csv")
 # cas <- smart_read("tests/testthat/cas500.csv")
 
@@ -9,9 +7,10 @@ test_that("Sort works for iid data", {
         d$height,
         sort(cas$height, na.last = TRUE)
     )
-    expect_equivalent(
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
 
@@ -21,13 +20,14 @@ svy <- svydesign(~dnum+snum, weights = ~pw, fpc = ~fpc1+fpc2, data = apiclus2)
 
 test_that("Sort works for surveys", {
     d <- sortVars(svy, "api00")
-    expect_is(d, "survey.design2")
+    expect_s3_class(d, "survey.design2")
     expect_equal(
         d$variables$api00,
         sort(svy$variables$api00, na.last = TRUE)
     )
-    expect_equivalent(
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
